@@ -39,6 +39,15 @@ if [ ! -d "$SAVE_DIR/posters" ]; then
     mkdir "$SAVE_DIR/posters";
 fi;
 
+if [ ! -f $HOME/.anyRemote/imdb-mf.sh ]; then
+    curl -k -g https://raw.github.com/webofunni/imdb-movie-fetcher/master/imdbmoviefetcher/imdb-mf.sh > $HOME/.anyRemote/imdb-mf.sh
+    chmod u+x $HOME/.anyRemote/imdb-mf.sh
+fi;
+
+if [ ! -f $HOME/.anyRemote/imdb-mf.sh ]; then
+   exit 1;
+fi
+
 POSTER_HASH=${MOVIE_HASH}".jpg"
 POSTER_SCALED_HASH=${MOVIE_HASH}"-${SCALE}.png"
 
@@ -56,8 +65,7 @@ if [ ! -f $SAVE_DIR/$MOVIE_HASH ]; then
     SEARCH_TITLE="$6"
   fi;
 
-  #echo "$CONF_DIR/Utils/imdb-mf.sh -m -t "$SEARCH_TITLE" > $SAVE_DIR/${MOVIE_HASH}.tmp"
-  $CONF_DIR/Utils/imdb-mf.sh -m -t "$SEARCH_TITLE" > $SAVE_DIR/${MOVIE_HASH}.tmp
+  $HOME/.anyRemote/imdb-mf.sh -m -t "$SEARCH_TITLE" > $SAVE_DIR/${MOVIE_HASH}.tmp
 
   GOT=`grep "imdb.com" $SAVE_DIR/${MOVIE_HASH}.tmp|grep "Poster URL" | wc -l`
   
