@@ -1,10 +1,10 @@
-#!/bin/bash
+#!/bin/sh
 
-if [ "x$1" == "x" ]; then
+if [ "x$1" = "x" ]; then
    exit 0;
 else
-   if [ "x$1" == "x-switch" ]; then
-     if [ "x$2" == "x" ]; then
+   if [ "x$1" = "x-switch" ]; then
+     if [ "x$2" = "x" ]; then
        exit 0;
      fi;
      
@@ -18,10 +18,10 @@ else
 fi; 
 
 WMCTRL=`which wmctrl 2> /dev/null`
-if [ "x$WMCTRL" == "x" ]; then
+if [ "x$WMCTRL" = "x" ]; then
 
   # wmctrl not installed
-  if [ "x$RUN" == "xYES" ]; then
+  if [ "x$RUN" = "xYES" ]; then
     killall $APP
     $APP 2> /dev/null &
     exit 0;
@@ -32,10 +32,10 @@ fi;
 IAM=`id -u`
 IS_RUN=`pgrep -u $IAM $APP|head -1` 
 
-if [ "x$IS_RUN" == "x" ]; then
+if [ "x$IS_RUN" = "x" ]; then
 
   # app not run yet
-  if [ "x$RUN" == "xYES" ]; then
+  if [ "x$RUN" = "xYES" ]; then
     $APP 2> /dev/null &
     exit 0;
   fi; 
@@ -44,10 +44,10 @@ else
   
   WIN_ID=`wmctrl -l -p|grep $IS_RUN|cut -d ' ' -f 1`
 
-  if [ "x$WIN_ID" == "x" ]; then
+  if [ "x$WIN_ID" = "x" ]; then
 
     # can not find app window, start it again
-    if [ "x$RUN" == "xYES" ]; then
+    if [ "x$RUN" = "xYES" ]; then
       killall $APP
       $APP 2> /dev/null &
     fi;
