@@ -1,8 +1,8 @@
 //
 // anyRemote
-// a bluetooth remote for your PC.
+// a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2009-2012 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2009-2014 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -279,7 +279,9 @@ int dbusInit()
     //logger(L_DBG, "dbusInit");
     GError *error = NULL;
 
+    #if (GLIB_MAJOR_VERSION <= 2 && GLIB_MINOR_VERSION < 36)
     g_type_init ();
+    #endif
 
     dbus_threads_init_default();
 
