@@ -39,7 +39,20 @@
 
 //#define DEFAULT_DEVICE  "/dev/rfcomm0"	seems JSR-82 phones is more usable now
 //#define DEFAULT_DEVICE  "bluetooth:19"
-#define DEFAULT_DEVICE  "bluetooth:19,tcp:5197,web:5080"
+
+#ifdef USE_AVAHI
+  #if defined USE_BLUEZ || defined USE_BT_FBSD 
+    #define DEFAULT_DEVICE  "bluetooth:19,tcp:5197,web:5080,avahi"
+  #else
+    #define DEFAULT_DEVICE  "tcp:5197,web:5080,avahi"
+  #endif
+#else
+  #if defined USE_BLUEZ || defined USE_BT_FBSD 
+    #define DEFAULT_DEVICE  "bluetooth:19,tcp:5197,web:5080"
+  #else
+    #define DEFAULT_DEVICE  "tcp:5197,web:5080"
+  #endif
+#endif
 
 #define RFCOMM_DEVICE   "rfcomm"
 #define AT_DEVICE   	"at:"
@@ -53,6 +66,7 @@
 #define STDIN_STREAM   	"stdin"
 #define WEB_SOCKET   	"web:"
 #define CMXML_SOCKET   	"cmxml:"
+#define AVAHI_USE   	"avahi"
 
 #define TOFILE   	"/anyremote.result"
 #define CMDFILE   	"/anyremote.command"
