@@ -40,7 +40,7 @@ extern char      tmp[MAXMAXLEN];
 #define HTTP_HEAD3 "<meta "
 #define HTTP_HEAD4 " content=\"text/html; charset=utf-8\">\n"
 #define HTTP_HEAD5 "</head>\n<body"
-#define HTTP_HEAD6 "><center>"
+#define HTTP_HEAD6 ">\n<center>"
 #define HTTP_SCRIPT      "<script>\nfunction clearForms()\n{\n  var i;\n  for (i = 0; (i < document.forms.length); i++) {\n    document.forms[i].reset();\n  }\n}\n</script>\n"
 #define HTTP_SCRIPT_CALL " onload=\"clearForms()\""
 
@@ -49,13 +49,41 @@ extern char      tmp[MAXMAXLEN];
 #define HTTP_HEAD_CSS_B1 "body {\n\tcolor:#"
 #define HTTP_HEAD_CSS_B2 "; \n\tbackground-color:#"
 #define HTTP_HEAD_CSS_B3 ";\n}\n"
-#define HTTP_HEAD_CSS_L1 "select {\n\tcolor:#"
+#define HTTP_HEAD_CSS_L1 "#menubutton{\n\tborder-radius:5px;\n\t-moz-border-radius:5px;\n\t-webkit-border-radius:10px;\n}\nselect {\n\tcolor:#"
 #define HTTP_HEAD_CSS_L3 "; \n\twidth:"
 #define HTTP_HEAD_CSS_BT1 "button {\n\tcolor:#"
 
+#define HTTP_HEAD_CSS_MENU1 ".menu {\n\twidth:"
+
+#define HTTP_HEAD_CSS_MENU2 "px;\n\theight:30px;\n\tfont-size:0.85em;\n\tposition: fixed;\n\tbottom: 0;\n}\n\
+.menu ul {\n\tpadding:0;\n\tmargin:0;\n\tlist-style-type:none;\n}\n\
+.menu input {\n\tpadding:0;\n\tmargin:0;\n}\n.menu ul ul,\n.menu ul input\n{\n\twidth:"
+
+#define HTTP_HEAD_CSS_MENU3 "px;\n}\n.menu li,\n.menu input {\n\tfloat:left;\n\twidth:"
+#define HTTP_HEAD_CSS_MENU4 "px;\n\tposition:relative;\n}\n.menu input {\n\tdisplay:block;\n\tfont-size:13px;\n\ttext-decoration:none;\n\tcolor:#ffffff;\n\twidth:"
+
+#define HTTP_HEAD_CSS_MENU5 "px;\
+  height:30px;\
+  border:1px solid #999999;\
+  border-width:1px 1px 0 0;\
+  background:#7582aa;\
+  padding-left:10px;\
+  line-height:29px;\n}\n.menu ul ul input:hover {\
+  color:#fff;\
+  background:#949eaa;\
+}\n.menu ul ul {\nvisibility:hidden;\
+  position:absolute;\
+  bottom:31px;\
+  left:0; \
+  width:" // W/2
+  
+#define HTTP_HEAD_CSS_MENU6 "px;\n}\n.menu ul ul input {\n\tbackground:#a4a8aa;\n\tcolor:#000;\n\theight:30px;\n\tline-height:1em;\n\tpadding:5px 10px\n\twidth:"
+
+#define HTTP_HEAD_CSS_MENU7 "px;\n}\n.menu ul input:hover {\n\tcolor:#000;\n\tbackground:#949eaa;\n}\n.menu ul li:hover ul {\n\tvisibility:visible;\n\theight:auto;\n}\n"
+
 #define HTTP_HEAD_CSS_99 "</style>\n"
 
-#define HTTP_TABLE1 "\n<table border=\"1\" cellpadding=\""
+#define HTTP_TABLE1 "\n<table border=\"0\" cellpadding=\""
 #define HTTP_TABLE2 "\" cellspacing=\"2\">\n<tbody>\n<tr>\n"
 //#define HTTP_TABLE3 "	<td style=\"vertical-align: top; text-align: center; width=5%;\">"
 #define HTTP_TABLE3 "	<td>"
@@ -73,9 +101,9 @@ extern char      tmp[MAXMAXLEN];
 #define HTTP_EDIT3 "</h4></center>\n<form action=\"\" method=\"post\">\n<input type=\"password\" name=\"http_editfield\" value=\""
 #define HTTP_EDIT4 "\" />\n<hr>"
 
-#define HTTP_TAIL "\n<h6><a href=\"/\">Redraw</a></h6>\n</center></body>\n</html>\n"
+#define HTTP_TAIL "\n<h6><a href=\"/\">Reload page</a></h6>\n</center></body>\n</html>\n"
 
-int _screenSize = 240;  // min(width,heigth)
+int _screenSize = 540;  // min(width,heigth)
 
 void initHtmlGenerator()
 {
@@ -83,7 +111,7 @@ void initHtmlGenerator()
     if (v1 != NULL) {
         _screenSize = atoi(v1);
         if (_screenSize <= 0) {
-            _screenSize = 240;
+            _screenSize = 540;
         }
         free(v1);
     }
@@ -105,16 +133,21 @@ string_t* fontHTML(const char* f)
     string_t* fh = stringNew("");
     
     if (strncmp(f,"small",5) == 0) {
-	    stringAppend(fh, "h6>");
+	    stringAppend(fh, "h6>\n");
     } else if (strncmp(f,"medium",6) == 0) {
-    	stringAppend(fh, "h4>");
+    	stringAppend(fh, "h4>\n");
     } else if (strncmp(f,"large",5) == 0) {
-    	stringAppend(fh, "h2>");
+    	stringAppend(fh, "h2>\n");
     }
     
     return fh;
 }
 
+static int getUseCSS()
+{
+    return 0;
+}
+
 char abuf[8];
 
 static char* getAccessKey(int index)
@@ -148,7 +181,7 @@ static void addFormMenu(int formId, string_t* page)
     case WM:
         if (listSingleLength(list) > 0) {
 
-            string_t* menu = stringNew("<HR>");
+            string_t* menu = stringNew("<hr>");
 
             //stringAppend(menu, "<div style=\"width:240px; overflow:auto;\">");
 
@@ -168,7 +201,7 @@ static void addFormMenu(int formId, string_t* page)
                 list = listSingleNext(list);
             }
             //stringAppend(menu, "</div>");
-            stringAppend(menu, "<HR>");
+            stringAppend(menu, "<hr>");
             stringAppend(page, menu->str);
             stringFree(menu,  BOOL_YES);
         }
@@ -176,24 +209,63 @@ static void addFormMenu(int formId, string_t* page)
 
     case LI:
     case EF:
+    
+        {
+            int listSz = listSingleLength(list);
 
-        if (listSingleLength(list) > 0) {
+            if (listSz > 0) {
 
-            string_t* menu = stringNew("");
+                int useCSS = getUseCSS();
 
-            int i = 0;
-            while(list) {
+                if (useCSS) {
 
-                stringAppend(menu, "<input name=\"action\" type=\"submit\" value=\"");
-                stringAppend(menu, ((string_t*) list->data)->str);
-                stringAppend(menu, "\">\n");
+                    string_t* menu = stringNew("<div class=\"menu\">\n<ul>\n");
+                    int i = 0;
+                    while(list) {
 
-                i++;
-                list = listSingleNext(list);
+                        if (i == 0) {
+                            stringAppend(menu, "<li><input name=\"action\" type=\"submit\" id=\"menubutton\" value=\"");
+                            stringAppend(menu, ((string_t*) list->data)->str);
+                            stringAppend(menu, "\"></li>\n");
+                        } else {
+                            if (i == 1 && listSz > 2) {
+                                stringAppend(menu, "<li>\n\t<li><input type=\"text\" id=\"menubutton\" value=\"More\">\n\t<ul>\n\t");
+                            }
+                            stringAppend(menu, "<li><input name=\"action\" type=\"submit\" id=\"menubutton\" value=\"");
+                            stringAppend(menu, ((string_t*) list->data)->str);
+                            stringAppend(menu, "\"></li>\n\t");
+                        }
+
+                        i++;
+                        list = listSingleNext(list);
+                    }
+                    if (listSz > 2) {
+                        stringAppend(menu, "</ul>\n");
+                    }
+                    stringAppend(menu, "</li>\n</ul>\n</div>\n");
+                    
+                    stringAppend(page, menu->str);
+                    stringFree(menu,  BOOL_YES);
+
+                } else {
+
+                    string_t* menu = stringNew("");
+                    
+                    int i = 0;
+                    while(list) {
+
+                        stringAppend(menu, "<input name=\"action\" type=\"submit\" id=\"menubutton\" value=\"");
+                        stringAppend(menu, ((string_t*) list->data)->str);
+                        stringAppend(menu, "\">\n");
+
+                        i++;
+                        list = listSingleNext(list);
+                    }
+                    stringAppend(menu, "<hr>");
+                    stringAppend(page, menu->str);
+                    stringFree(menu,  BOOL_YES);
+                }
             }
-            stringAppend(menu, "<HR>");
-            stringAppend(page, menu->str);
-            stringFree(menu,  BOOL_YES);
         }
         break;
     }
@@ -213,17 +285,26 @@ string_t* renderFormHead(int form, const char* caption, const char* fg, const ch
     stringAppend(head, HTTP_HEAD4);
 
     // Do some CSS styling
+    int useCSS = getUseCSS();
+    
     stringAppend(head, HTTP_HEAD_CSS_0);
     //stringAppend(head, HTTP_HEAD_CSS_1);
 
+    char buf[16];
+    sprintf(buf,"%d",_screenSize);
+    
     stringAppend(head, HTTP_HEAD_CSS_B1);
     stringAppend(head, fg);
     stringAppend(head, HTTP_HEAD_CSS_B2);
     stringAppend(head, bg);
+    
+    if (form == LI) {
+        stringAppend(head, ";\n\twidth:");
+        stringAppend(head, buf);
+        stringAppend(head, "px");
+    }
     stringAppend(head, HTTP_HEAD_CSS_B3);
     
-    char buf[16];
-    sprintf(buf,"%d",_screenSize);
 
     if (form == CF) {
 
@@ -231,7 +312,9 @@ string_t* renderFormHead(int form, const char* caption, const char* fg, const ch
         stringAppend(head, fg);
         stringAppend(head, HTTP_HEAD_CSS_B2);
         stringAppend(head, bg);
-        stringAppend(head, ";\n\tborder-style:none;\n}\n");
+        stringAppend(head, ";\n\tborder-radius:10px;\n\t-moz-border-radius:10px;\n\t-webkit-border-radius:10px;\n\tborder:2px solid "); 
+        stringAppend(head, fg);
+        stringAppend(head, ";}\n");
         stringAppend(head, "p.widthScr {\n\twidth:"); 
 	    stringAppend(head, buf);
         stringAppend(head, "px;\n\toverflow:auto;\n}\n");
@@ -253,6 +336,32 @@ string_t* renderFormHead(int form, const char* caption, const char* fg, const ch
         stringAppend(head, buf);
         stringAppend(head, "px;\n\toverflow:auto;\n}\n");
     }
+    
+    if (useCSS) {
+        char w2[16];
+        sprintf(w2,"%d",_screenSize/2);
+        
+        char w2_11[16];
+        sprintf(w2_11,"%d",_screenSize/2-11);
+
+        char w2_10[16];
+        sprintf(w2_10,"%d",_screenSize/2+10);
+        
+        stringAppend(head, HTTP_HEAD_CSS_MENU1);
+        stringAppend(head, buf);
+        stringAppend(head, HTTP_HEAD_CSS_MENU2);
+        stringAppend(head, w2);
+        stringAppend(head, HTTP_HEAD_CSS_MENU3);
+        stringAppend(head, w2);
+        stringAppend(head, HTTP_HEAD_CSS_MENU4);
+        stringAppend(head, w2_11);
+        stringAppend(head, HTTP_HEAD_CSS_MENU5);
+        stringAppend(head, w2);
+        stringAppend(head, HTTP_HEAD_CSS_MENU6);
+        stringAppend(head, w2_10);
+        stringAppend(head, HTTP_HEAD_CSS_MENU7);
+    }
+    
     stringAppend(head, HTTP_HEAD_CSS_99);
 
     stringAppend(head, HTTP_HEAD5);
@@ -468,7 +577,7 @@ string_t* renderListHTMLForm(string_t* no_use, int port)
     }
     mutexUnlock(M_STATE);
 
-    stringAppend(page, "</select>\n<hr>");
+    stringAppend(page, "</select>\n<hr>\n");
 
     addFormMenu(LI, page);
 
@@ -572,9 +681,7 @@ string_t* renderPassHTMLForm(string_t* no_use, int port)
     stringAppend(page, "<input name=\"action\" type=\"submit\" value=\"Ok\">\n");
     stringAppend(page, "<input name=\"action\" type=\"submit\" value=\"Back\">\n");
 
-    stringAppend(page, "<HR>");
-    
-    stringAppend(page, "</form>\n</");
+    stringAppend(page, "<hr>\n</form>\n</");
     stringAppend(page, fontSpec->str);
     stringAppend(page, "\n");
     stringAppend(page, HTTP_TAIL);
