@@ -47,6 +47,7 @@
 #include "thread.h"
 #include "loop.h"
 #include "alarm.h"
+#include "avahi.h"
 
 extern void freeDisplay();	// from xemulate.h
 
@@ -94,6 +95,10 @@ void aboutToExit()
 
         threadJoin(T_DISP);
     }
+    
+    #ifdef USE_AVAHI
+    stopAvahi(); 
+    #endif
 
     stillRun = BOOL_NO;
 
@@ -231,6 +236,12 @@ int main(int argc, char *argv[])
     if (getFrontEnd() > 0) {
         queueNew(Q_FE);
     }
+    
+    #ifdef USE_AVAHI
+    if (parsePortsForAvahi()) {
+        threadNew(T_AVAHI,startAvahi,NULL,JOINABLE);
+    }
+    #endif
 
     loopStart();
 
