@@ -1,8 +1,8 @@
 //
 // anyRemote
-// a bluetooth remote for your PC.
+// a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2013 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2014 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -1303,11 +1303,13 @@ static int storeOtherCmd(cmdItem* ci, char *cmd)
     return storeDescription(ci, cmd);
 }
 
-int storeCmds(SingleList** pcommands, char *value)
+int storeCmds(SingleList** pcommands, const char *inval)
 {
     int cmdId;
 
     size_t no_sub = cmdByCmd->re_nsub+1;
+    
+    char *value = strdup(inval);
 
     //printf("storeCmds() %s (%d)\n", value, (int)no_sub);
 
@@ -1448,13 +1450,16 @@ int storeCmds(SingleList** pcommands, char *value)
         start +=step;
         //printf("REST OF CMDS %s\n", value+start);
     }   // while
+    
     free(result);
+    free(value);
+    
     result = NULL;
 
     return EXIT_OK;
 }
 
-static int storeKey(mode* cMode, char *tag, char *value)
+static int storeKey(mode* cMode, const char *inTag, const char *value)
 {
     type_key* It = NULL;
     int ret = EXIT_OK;
@@ -1462,10 +1467,13 @@ static int storeKey(mode* cMode, char *tag, char *value)
     //printf("storeKey %s %s\n", cMode->name->str,tag);
     
     type_key **head = &(cMode->keys);
+    
+    char* tag = strdup(inTag);
 
     normalizeSequence(&tag);
 
     if(cMode && findExact(cMode, tag)) {
+        free(tag);
         return EXIT_OK;  // do not overwrite existing items
     }
 
@@ -1501,7 +1509,8 @@ static int storeKey(mode* cMode, char *tag, char *value)
     } else {
         It->commands = NULL;
     }
-
+    free(tag);
+    
     return ret;
 }
 
@@ -1641,17 +1650,36 @@ static int loadKeys(FILE *fp)
     return EXIT_OK;
 }
 
+static struct 
+{ 
+    const char* key;
+    const char* value;
+} 
+keyTable[] = {
+  {"_GET_ICON_($$)",  
+   "ExecAndSet(image,icon,I=`find $(Home)/.anyRemote/Icons/$(Index) $(CfgDir)/Icons/$(Index) -name $(Param).png 2> /dev/null|grep -v svn`;echo \"$(Param),$I\");"},
+  {"_GET_COVER_($$)", 
+   "ExecAndSet(image,cover,I=`find $(Home)/.anyRemote/Covers $(CfgDir)/Icons/common -name \"$(Param).*\" 2> /dev/null|grep -v svn`;convert -resize $(Index)x$(Index) -depth 8 -background transparent $I \"$(TmpDir)\"/$(Param)_$(Index).png 2> /dev/null;echo \"$(Param),$(TmpDir)/$(Param)_$(Index).png\");"},
+  
+  {"_MM_($$)",        "Emulate(mousermove,$(Index),$(Param));"},
+  {"_MB_($$)",        "Emulate(mouse,$(Index));"},
+  {"_KB_($$)",        "Emulate(key,$(Param));"},
+  {"_KP_($$)",        "Emulate(keydown,$(Param));"},
+  {"_KR_($$)",        "Emulate(keyup,$(Param));"},
+  {"_KM_($$)",        "Emulate(modifier,$(Index),$(Param));"},
+  
+  {NULL,              NULL}
+};
+
 static void loadInternal()
 {
     mode* im = getInternalMode();
 
-    char cmd_i[] = "_GET_ICON_($$)";
-    char val_i[] = "ExecAndSet(image,icon,I=`find $(Home)/.anyRemote/Icons/$(Index) $(CfgDir)/Icons/$(Index) -name $(Param).png 2> /dev/null|grep -v svn`;echo \"$(Param),$I\");";
-    storeKey(im, cmd_i, val_i);
-
-    char cmd_c[] = "_GET_COVER_($$)";
-    char val_c[] = "ExecAndSet(image,cover,I=`find $(Home)/.anyRemote/Covers $(CfgDir)/Icons/common -name \"$(Param).*\" 2> /dev/null|grep -v svn`;convert -resize $(Index)x$(Index) -depth 8 -background transparent $I \"$(TmpDir)\"/$(Param)_$(Index).png 2> /dev/null;echo \"$(Param),$(TmpDir)/$(Param)_$(Index).png\");";
-    storeKey(im, cmd_c, val_c);
+    int i=0;
+    while (keyTable[i].key) {
+        storeKey(im, keyTable[i].key, keyTable[i].value);
+        i++;
+    }
 }
 
 int load_cfg(const char *mfile, int isInit)
