@@ -76,14 +76,20 @@ static void freePeer(void* data)
     free(peer);
 }
 
-static int countConnections()
+
+// do not take into account connection-less peers (HTML + XML)
+static int countConnections(int all)
 {
     int cnum = 0;
     SingleList* list = _connections;
+    //INFO2("[DS]: countConnections() enter %d", listSingleLength(list));
+    
     while (list) {
        ConnectInfo* peer = (ConnectInfo*) list->data;
        if (peer->state == PEER_CONNECTED) {
-           cnum++;
+           if (all || (peer->mode != SERVER_WEB && peer->mode != SERVER_CMXML)) {
+                cnum++;
+           }
        }
        list = listSingleNext(list);
     }
@@ -236,6 +242,7 @@ static int addPeer(char * portIn)
     // 6. local:/some/path                                    used with java client, like 1, but no AT commands
     // 7. ilirc:/dev/something                                 like 1, but no AT commands
     // 8. stdio                                                used with java client, like 1, but no AT commands
+    // 9. avahi                                                skipped here
 
 
     ConnectInfo* peer = allocPeer();
@@ -401,6 +408,13 @@ static int addPeer(char * portIn)
         peer->portStr = stringNew(strPort);
         DEBUG2("[DS]: Serial Client mode. Use device %s", peer->portStr->str);
 
+    } else if (strstr(portIn, AVAHI_USE)) {
+       
+        // do nothing
+        logger(L_DBG, "[DS]: Avahi flag is ON");
+        freePeer(peer);
+        return EXIT_OK;
+       
     } else {
 
         peer->mode  = CLIENT_AT;
@@ -498,7 +512,9 @@ int openPeers()
 
             int ret1 = _peerHandlers[peer->mode].openConnection(peer);
 
-            INFO2("[DS]: Open peer connect mode %d fdescriptor %d", peer->mode, _peerHandlers[peer->mode].descriptor(peer));
+            if (peer->state != PEER_DISCONNECTED) {  // for TCP (etc.) connection still can be in DISCONNECT
+                INFO2("[DS]: Open peer connect mode %d fdescriptor %d", peer->mode, _peerHandlers[peer->mode].descriptor(peer));
+            }
 
             if (ret1 != EXIT_NOK) {
                 ret = ret1;
@@ -701,6 +717,7 @@ static void syncPeer(ConnectInfo* peer)
                 
                 int fd = _peerHandlers[peer->mode].descriptor(peer);
                 if (fd >= 0) {
+                    INFO2("[DS]: syncPeer write to peer %d %d", f, fd);
                     writePeer(fd, content->str, content->len);
                 }
 	            stringFree(content, BOOL_YES);
@@ -1054,7 +1071,7 @@ int readPeers(string_t* buffer)
                             //DEBUG2("[DS]: readPeers() peer with mode %d readable", peer->mode);
                             int rr = doReadPeer(peer, buffer, fd);
                             if (rr == EOF) {
-                                int cnum = countConnections();
+                                int cnum = countConnections(0);
 
                                 // no more connections
                                 if (cnum == 0) { 
@@ -1064,9 +1081,9 @@ int readPeers(string_t* buffer)
                             }
                         } else if (peer->state == PEER_WAIT_ACCEPT) {
 
-                            //DEBUG2("[DS]: readPeers() accept connection peer with mode %d", peer->mode);
+                            DEBUG2("[DS]: readPeers() accept connection peer with mode %d", peer->mode);
                             if (_peerHandlers[peer->mode].acceptConnection(peer) == EXIT_OK) {
-                                int cnum = countConnections();
+                                int cnum = countConnections(1);
 
                                 // do this only on first connect
                                 if (cnum == 1) {
@@ -1578,13 +1595,13 @@ boolean_t checkActiveCall()
         ConnectInfo* cn = (ConnectInfo*) list->data;
 
         if (cn->mode == CLIENT_RFCOMM) {
-        if (rfcommCheckActiveCall(cn)) {
-            return BOOL_YES;
-        }
+            if (rfcommCheckActiveCall(cn)) {
+                return BOOL_YES;
+            }
         } else if (cn->mode == CLIENT_AT) { 
-        if (serialCheckActiveCall(cn)) {
-            return BOOL_YES;
-        }
+            if (serialCheckActiveCall(cn)) {
+                return BOOL_YES;
+            }
         }
         list = listSingleNext(list);
     }
@@ -1598,13 +1615,13 @@ boolean_t hasActiveCall()
         ConnectInfo* cn = (ConnectInfo*) list->data;
 
         if (cn->mode == CLIENT_RFCOMM) {
-        if (rfcommHasActiveCall(cn)) {
-            return BOOL_YES;
-        }
+            if (rfcommHasActiveCall(cn)) {
+                return BOOL_YES;
+            }
         } else if (cn->mode == CLIENT_AT) { 
-        if (serialHasActiveCall(cn)) {
-            return BOOL_YES;
-        }
+            if (serialHasActiveCall(cn)) {
+                return BOOL_YES;
+            }
         }
         list = listSingleNext(list);
     }
