@@ -199,9 +199,8 @@ int openL2capPort(ConnectInfo* connInfo)
     cn->record               = NULL;
 
     if ((cn->serverFileDescriptor = socket(PF_BLUETOOTH, SOCK_SEQPACKET|SOCK_CLOEXEC, BTPROTO_L2CAP)) < 0) {
-        logger(L_ERR, "opening socket");
-        printf("ERROR: opening socket\n");
-
+        logger(L_ERR, "opening BT/L2CAP socket");
+        printf("ERROR: opening BT/L2CAP socket\n");
         return -1;
     }
 
