@@ -1613,6 +1613,16 @@ static pointer_t webServerMain(pointer_t data)
         if (isAllowed(buf)) {
             INFO2("[WS]: webServerMain: connection accepted");
             
+            /*if (conn->state == PEER_WAIT_ACCEPT) {
+                wMessage* wm = (wMessage*) malloc(sizeof(wMessage));
+                wm->button = -1;
+                wm->string = stringNew("(Connect)");
+
+                sendToWebServer(wm);
+                
+                conn->state = PEER_CONNECTED;
+            }*/
+            
             _WebClientConnection* ptr = (_WebClientConnection*) malloc(sizeof(_WebClientConnection));
             ptr->serverPort     = conn->port;
             ptr->connDescriptor = s;
@@ -1672,7 +1682,7 @@ int openWeb(ConnectInfo* conn)
     }
     
      
-    conn->state = PEER_CONNECTED;
+    conn->state = PEER_CONNECTED; //PEER_WAIT_ACCEPT;
     return EXIT_OK;
 }
 
@@ -1722,34 +1732,34 @@ int checkWebPort(char* buf, int capacity)
 void closeWebPort(ConnectInfo* conn, int final)
 {
     INFO2("[WS]: closeWebPort %d", final);
-    _WebConnection* cn = (_WebConnection*) conn->connectionData;
-
-    // close all sockets
-    if (cn->fileDescriptor != -1) {
-        close(cn->fileDescriptor);
-        cn->fileDescriptor = -1;
-    }
-
-    mutexLock(M_WEB);
-
-    //INFO2("[WS]: clientSockets before cleanup #%d", listSingleLength(cn->clientSockets));
-
-    SingleList* list = cn->clientSockets;
-    while (list) {
-
-        int clientFD = CAST_POINTER_TO_INT(list->data);
-        if (clientFD > 0) {
-            close(clientFD);
-        }
-        list = listSingleNext(list);
-    }
-
-    listSingleFree(cn->clientSockets);
-    cn->clientSockets = NULL;
-
-    mutexUnlock(M_WEB);
-
     if (final) {
+        _WebConnection* cn = (_WebConnection*) conn->connectionData;
+
+        // close all sockets
+        if (cn->fileDescriptor != -1) {
+            close(cn->fileDescriptor);
+            cn->fileDescriptor = -1;
+        }
+
+        mutexLock(M_WEB);
+
+        //INFO2("[WS]: clientSockets before cleanup #%d", listSingleLength(cn->clientSockets));
+
+        SingleList* list = cn->clientSockets;
+        while (list) {
+
+            int clientFD = CAST_POINTER_TO_INT(list->data);
+            if (clientFD > 0) {
+                close(clientFD);
+            }
+            list = listSingleNext(list);
+        }
+
+        listSingleFree(cn->clientSockets);
+        cn->clientSockets = NULL;
+
+        mutexUnlock(M_WEB);
+
         runWeb = BOOL_NO;
 
         if (cn->serverIP) {
@@ -1863,7 +1873,7 @@ int writeWebConnStr(const char* value, int mode)
             stringAppend(wm->string,sz);
             stringAppend(wm->string,",");
             stringAppend(wm->string,icon);
-	    stringAppend(wm->string,")");
+            stringAppend(wm->string,")");
         }
 
     } else if (strncmp(token,"Get(cover_size",14) == 0) {
