@@ -408,7 +408,7 @@ void printHelp()
     printf(" -h|--help  print this help\n");
     printf(" -v|--version  print version of anyRemote\n");
     printf(" -f /path/to/file  specify configuration file\n");
-    printf(" -s peer[,peer ...],  possible values\n");
+    printf(" -s peer[,peer ...], where peer possible values are\n");
     printf("    bluetooth:<channel> (Server mode - bluetooth connection)\n");
     printf("    tcp:<port>          (Server mode - TCP/IP connection)\n");
     printf("    web:<port>          (Server mode - Web interface)\n");
@@ -421,13 +421,14 @@ void printHelp()
     printf("    /dev/ircomm#        (AT mode - IR connection)\n");
     printf("    ilirc:<AF_LOCAL socket file> (use with inputlircd)\n");
     printf("    stdin\n");
+    printf("    avahi - register SDP service using Avahi\n");
     printf("  Default peer value is bluetooth:19,tcp:5197,web:5080\n");
     printf("  It is possible to specify several peers for Server mode configuration files only\n");
     printf("  It is possible to specify only single peer of web: or cmxml: type\n");
     printf(" -log print verbose logging information to $HOME/.anyRemote/anyremote.log\n");
     printf(" -a	reconnect automatically in case of connection failure, used only in AT-mode\n");
     printf(" -fe <port> work as backend for GUI frontend. Use specified port to connect to frontend.\n");
-    printf(" -name <SDP service name> if bluetooth connection is used, allows one to specify SDP service name\n");
+    printf(" -name <SDP service name> if bluetooth or TCP/IP connection is used, allows one to specify SDP service name\n");
     printf(" -password ask password on connect\n");
     printf("           password should be stored in $HOME/.anyRemote/password file in a plain text\n");
     printf(" -u|--user <username> if started from root, allows to set effective user ID to specified user\n\n");
